@@ -32,6 +32,7 @@ from pytensor.graph.op import Op
 from pytensor.tensor import (
     abs,
     and_,
+    broadcast_to,
     ceil,
     clip,
     concatenate,
@@ -47,6 +48,8 @@ from pytensor.tensor import (
     exp,
     flatten,
     floor,
+    full,
+    full_like,
     ge,
     gt,
     le,
@@ -55,9 +58,12 @@ from pytensor.tensor import (
     logaddexp,
     logsumexp,
     lt,
+    matmul,
     maximum,
+    mean,
     minimum,
     neq,
+    ones,
     ones_like,
     or_,
     prod,
@@ -73,6 +79,7 @@ from pytensor.tensor import (
     tan,
     tanh,
     where,
+    zeros,
     zeros_like,
 )
 from pytensor.tensor.linalg import solve_triangular
@@ -87,6 +94,7 @@ from pymc.pytensorf import floatX, ix_, largest_common_dtype
 __all__ = [
     "abs",
     "and_",
+    "broadcast_to",
     "ceil",
     "clip",
     "concatenate",
@@ -100,6 +108,8 @@ __all__ = [
     "erfcinv",
     "erfinv",
     "exp",
+    "full",
+    "full_like",
     "flatten",
     "floor",
     "ge",
@@ -110,9 +120,12 @@ __all__ = [
     "logaddexp",
     "logsumexp",
     "lt",
+    "matmul",
     "maximum",
+    "mean",
     "minimum",
     "neq",
+    "ones",
     "ones_like",
     "or_",
     "prod",
@@ -128,6 +141,7 @@ __all__ = [
     "tan",
     "tanh",
     "where",
+    "zeros",
     "zeros_like",
     "kronecker",
     "cartesian",
