@@ -70,7 +70,7 @@ class ModelValuedVar(ModelVar):
         dims = self._parse_dims(rv, *dims)
         if value is not None:
             assert isinstance(value, Variable)
-            assert rv.type.in_same_class(value.type)
+            assert rv.type.dtype == value.type.dtype
             return Apply(self, [rv, value, *dims], [rv.type(name=rv.name)])
 
 
